@@ -1,7 +1,6 @@
 import os
 
-from bottle import Bottle
-from bottle import run
+from bottle import Bottle, run
 
 app = Bottle()
 
@@ -16,5 +15,6 @@ if __name__ == '__main__':
     config_path = os.path.join(cur_dir, 'conf/test.yaml')
 
     from swagger_ui import api_doc
+
     api_doc(app, config_path=config_path, url_prefix='/api/doc')
     run(app, host='0.0.0.0', port=8989, debug=True)
