@@ -10,9 +10,11 @@ class HelloWorldHandler(tornado.web.RequestHandler):
 
 
 def make_app():
-    return tornado.web.Application([
-        (r'/hello/world', HelloWorldHandler),
-    ])
+    return tornado.web.Application(
+        [
+            (r'/hello/world', HelloWorldHandler),
+        ]
+    )
 
 
 if __name__ == '__main__':
@@ -24,6 +26,7 @@ if __name__ == '__main__':
     # tornado_api_doc(app, config_path=config_path, url_prefix='/api/doc/')
 
     from swagger_ui import api_doc
+
     api_doc(app, config_path=config_path, url_prefix='/api/doc/', editor=True)
 
     app.listen(8989)
